@@ -1,12 +1,4 @@
-"""This module contains library wide configuration.
-"""
-
-__authors__ = ["J. Garriga"]
-__license__ = "MIT"
-__date__ = "19/11/2020"
-
-
-class Config(object):
+class Config:
     """
     Class containing shared global configuration for the darfix project.
 
