@@ -2,13 +2,18 @@ __authors__ = ["J. Garriga"]
 __license__ = "MIT"
 __date__ = "28/02/2020"
 
-import cv2
-import numpy
-
 from enum import Enum
 
+import numpy
 from silx.image import sift
 
+try:
+    import cv2
+except ImportError:
+    has_cv2 = False
+else:
+    has_cv2 = True
+
 
 class Method(Enum):
     """
@@ -33,7 +38,6 @@ class ComponentsMatching:
     """
 
     def __init__(self, components):
-
         self.components = components
 
     def _create_descriptors(self):
@@ -56,7 +60,6 @@ class ComponentsMatching:
         return descripted_components
 
     def _create_sift_keypoints(self):
-
         keypoints = []
 
         for array in self.components:
@@ -94,6 +97,10 @@ class ComponentsMatching:
             with the matching info per pair of components.
         :rtype: (dict, dict)
         """
+        if not has_cv2:
+            raise RuntimeError(
+                "Unable to match components without opencv-python. Please install it."
+            )
         if id1 is None or id2 is None:
             assert len(self.components) == 2, "Index of components must be given"
             id1 = 0
@@ -110,7 +117,6 @@ class ComponentsMatching:
                 if component1.descriptor is not None:
                     for j, component2 in enumerate(self.descriptors[id2]):
                         if component2.descriptor is not None:
-
                             # Match descriptors
                             good[(i, j)] = numpy.array(
                                 bf.match(component1.descriptor, component2.descriptor)
@@ -121,7 +127,6 @@ class ComponentsMatching:
             for x, y in sorted(good, key=lambda match: len(good[match]), reverse=True):
                 # Only add match if neither x nor y are already in the list.
                 if x not in final_matches.keys() and y not in final_matches.values():
-
                     kp1 = []
                     kp2 = []
                     for match in good[(x, y)]:
