@@ -3,11 +3,12 @@ __license__ = "MIT"
 __date__ = "13/09/2019"
 
 
-import numpy
 import random
 
+import numpy
+
 from .autofocus import normalized_variance
-from .imageRegistration import apply_shift
+from .imageRegistration import apply_opencv_shift
 
 
 class GeneticShiftDetection:
@@ -24,7 +25,6 @@ class GeneticShiftDetection:
     """
 
     def __init__(self, data, optimal_shift):
-
         assert optimal_shift.shape[1] == len(
             data
         ), "Optimal shift\
@@ -63,7 +63,7 @@ class GeneticShiftDetection:
             result = numpy.zeros(self.data[0].shape)
             n_shift = self.optimal_shift + population[i]
             for iFrame in range(len(self.data)):
-                result += apply_shift(
+                result += apply_opencv_shift(
                     self.data[iFrame], n_shift[:, iFrame], shift_approach
                 )
             scores.append(normalized_variance(result))
