@@ -2,17 +2,31 @@ __authors__ = ["J. Garriga"]
 __license__ = "MIT"
 __date__ = "07/07/2021"
 
-
 import enum
-import numpy
-import cv2
-from scipy.ndimage import center_of_mass, fourier_shift
-import skimage
-from skimage import registration
+import warnings
 
+try:
+    import cv2
+except ImportError:
+    has_cv2 = False
+else:
+    has_cv2 = True
+
+import numpy
+import skimage
+
+try:
+    from skimage.registration import phase_cross_correlation
+except ImportError:
+    from skimage.feature import register_translation as phase_cross_correlation
+
+from packaging.version import Version
+from scipy.ndimage import center_of_mass
+from scipy.ndimage import fourier_shift
 from silx.utils.enum import Enum as _Enum
 
 from darfix.io import utils
+
 from .autofocus import normalized_variance
 
 
@@ -48,7 +62,7 @@ def diff_com(img1, img2):
     return numpy.array(center_of_mass(img2)) - numpy.array(center_of_mass(img1))
 
 
-def find_shift(img1, img2, upsample_factor=1000):
+def find_shift(img1, img2, upsample_factor=1000) -> numpy.ndarray:
     """
     Uses the function ``register_translation`` from skimage to find the shift between two images.
 
@@ -56,18 +70,27 @@ def find_shift(img1, img2, upsample_factor=1000):
     :param array_like img2: second image, must be same dimensionsionality as ``img1``.
     :param int upsample_factor: optional.
     """
-    if skimage.__version__ >= "0.19.0":
-        return registration.phase_cross_correlation(
+    version = Version(skimage.__version__)
+
+    if version >= Version("0.21.0"):
+        shifts, _, _ = phase_cross_correlation(
             img1,
             img2,
             upsample_factor=upsample_factor,
-            return_error=False,
             normalization=None,
         )
-    else:
-        return registration.phase_cross_correlation(
-            img1, img2, upsample_factor=upsample_factor, return_error=False
+        return shifts
+    if version >= Version("0.19.0"):
+        return phase_cross_correlation(
+            img1,
+            img2,
+            upsample_factor=upsample_factor,
+            return_error=False,  # deprecated in 0.21 and removed in 0.22
+            normalization=None,
         )
+    return phase_cross_correlation(
+        img1, img2, upsample_factor=upsample_factor, return_error=False
+    )
 
 
 def _numpy_fft_shift(img, dx, dy):
@@ -106,6 +129,7 @@ def _opencv_fft_shift(img, dx, dy):
     Each value of each matrix (Nx, Ny) corresponds to the coordinate of the corresponding pixel
     divided by the size of the image.
     """
+
     Nx, Ny = numpy.meshgrid(numpy.fft.fftfreq(xnum), numpy.fft.fftfreq(ynum))
     dft = cv2.dft(img, flags=cv2.DFT_COMPLEX_OUTPUT)
     dft = dft[..., 0] + 1j * dft[..., 1]
@@ -128,7 +152,7 @@ def _scipy_fft_shift(img, dx, dy):
     return numpy.fft.ifftn(fourier_shift(numpy.fft.fftn(img), [dy, dx])).real
 
 
-def apply_shift(img, shift, shift_approach="fft"):
+def apply_opencv_shift(img, shift, shift_approach="fft"):
     """
     Function to apply the shift to an image.
 
@@ -138,6 +162,10 @@ def apply_shift(img, shift, shift_approach="fft"):
     :param Union[`linear`, `fft`] shift_approach: The shift method to be used to apply the shift.
     :returns: real ndarray
     """
+    if not has_cv2:
+        raise RuntimeError(
+            "opencv-python is not installed. Unable to apply shift with it. Please install it."
+        )
     shift_approach = ShiftApproach.from_value(shift_approach)
     if shift_approach == ShiftApproach.LINEAR:
         img = img.astype(numpy.int16)
@@ -187,7 +215,7 @@ def improve_linear_shift(
         result = numpy.zeros(data[0].shape)
         for iFrame in iData:
             shift = h_ * v * iFrame
-            result += apply_shift(data[iFrame], shift, shift_approach)
+            result += apply_opencv_shift(data[iFrame], shift, shift_approach)
 
         # Compute score using normalized variance
         # TODO: add more autofocus options
@@ -207,16 +235,20 @@ def shift_detection(data, steps, shift_approach="linear"):
     :rtype: ndarray
     """
     if len(data) == 0:
-        return []
+        return numpy.array([])
     shape = data[0].shape
     first_sum = numpy.zeros(shape)
     second_sum = numpy.zeros(shape)
+    imid = len(data) / 2
     for i in range(len(data)):
-        if i < len(data) / 2:
+        if i < imid:
             first_sum += data[i]
         else:
             second_sum += data[i]
-    shift = find_shift(first_sum, second_sum, 1000)
+    if not first_sum.any() or not second_sum.any():
+        shift = numpy.zeros(second_sum.ndim)
+    else:
+        shift = find_shift(first_sum, second_sum, 1000)
     v = normalize(shift)
     v_ = 2 * shift / len(data)
     h = numpy.sqrt(v_[0] ** 2 + v_[1] ** 2)
@@ -266,20 +298,19 @@ def shift_correction(data, n_shift, shift_approach="fft", callback=None):
     utils.advancement_display(0, len(data), "Applying shift")
 
     for count, frame in enumerate(data):
-        shifted_data[count] = apply_shift(frame, shift[:, count], shift_approach)
+        shifted_data[count] = apply_opencv_shift(frame, shift[:, count], shift_approach)
         utils.advancement_display(count + 1, len(data), "Applying shift")
         if callback:
             callback(int(count / len(data) * 100))
 
-    if data.dtype.kind == "f":
-        if data.dtype.itemsize > shifted_data.dtype.itemsize:
-            import warnings
+    with warnings.catch_warnings():
+        warnings.simplefilter("always")
 
-            warnings.warn("Precision loss to float32")
-    else:
-        import warnings
-
-        warnings.warn("Data cast to float32")
+        if data.dtype.kind == "f":
+            if data.dtype.itemsize > shifted_data.dtype.itemsize:
+                warnings.warn("Precision loss to float32")
+        else:
+            warnings.warn("Data cast to float32")
 
     return shifted_data
 
@@ -316,7 +347,9 @@ def random_search(data, optimal_shift, iterations, sigma=None, shift_approach="l
         for iFrame in range(len(data)):
             shifty = n_shift[0][iFrame]
             shiftx = n_shift[1][iFrame]
-            result += [apply_shift(data[iFrame], [shifty, shiftx], shift_approach)]
+            result += [
+                apply_opencv_shift(data[iFrame], [shifty, shiftx], shift_approach)
+            ]
         score = normalized_variance(result)
         if best_score < score:
             best_result = n_shift
