@@ -2,10 +2,13 @@ __authors__ = ["J. Garriga"]
 __license__ = "MIT"
 __date__ = "13/05/2020"
 
+import warnings
+
 import numpy
 from sklearn.decomposition import IncrementalPCA
 
 from darfix.io import utils
+
 from .base import Base
 
 
@@ -105,9 +108,11 @@ class IPCA(Base):
                             "Fitting data with IPCA",
                         )
                         break
-                    self._ipca.partial_fit(
-                        self.data[self.indices, i : i + self._chunksize].T
-                    )
+
+                    with numpy.errstate(invalid="ignore", divide="ignore"):
+                        self._ipca.partial_fit(
+                            self.data[self.indices, i : i + self._chunksize].T
+                        )
                     utils.advancement_display(
                         i + self._chunksize, self.num_features, "Fitting data with IPCA"
                     )
@@ -234,8 +239,11 @@ class IPCA(Base):
         self._singular_values = self._ipca.singular_values_
 
     def fit_transform(self, max_iter=1, error_step=None, W=None, H=None):
-
         self.W = None
         self.H = None
 
-        Base.fit_transform(self, max_iter=max_iter, error_step=error_step)
+        with warnings.catch_warnings():
+            # scikit_learn<1.1.1
+            warnings.filterwarnings("always", "Mean of empty slice.", RuntimeWarning)
+            with numpy.errstate(invalid="ignore", divide="ignore"):
+                Base.fit_transform(self, max_iter=max_iter, error_step=error_step)
