@@ -1,13 +1,11 @@
-__authors__ = ["J. Garriga"]
-__license__ = "MIT"
-__date__ = "12/04/2022"
-
 from silx.gui import qt
 from silx.gui.colors import Colormap
 from silx.gui.plot.StackView import StackViewMainWindow
+
 import darfix
-from darfix.core.dataset import Operation
-from .operationThread import OperationThread
+from darfix import dtypes
+from darfix.core.data import Operation
+from darfix.gui.utils.message import missing_dataset_msg
 
 
 class BinningWidget(qt.QMainWindow):
@@ -15,16 +13,34 @@ class BinningWidget(qt.QMainWindow):
     Widget to bin the data for fastest processing
     """
 
-    sigComputed = qt.Signal(float)
+    sigComputed = qt.Signal()
+    """Emit once the user has validated the binned dataset"""
+
+    sigApply = qt.Signal()
+    """Emit when the user ask to apply the binning"""
+
+    sigScaleChanged = qt.Signal(float)
+    """Emit when the scale changed"""
+
+    sigAbort = qt.Signal()
+    """Emit when user request to abort processing"""
 
     def __init__(self, parent=None):
         qt.QMainWindow.__init__(self, parent)
 
-        self._scale = None
+        self._display_tooltip_msg = True
 
         widget = qt.QWidget()
         layout = qt.QGridLayout()
 
+        self._dataset = None
+        # original dataset, the one treated. Keep it to be able to re-apply modifications
+        self._update_dataset = None
+        # dataset with applied modifications. This is the one displayed
+        self.indices = None
+        self.bg_indices = None
+        self.bg_dataset = None
+
         self._scaleLE = qt.QLineEdit("1")
         validator = qt.QDoubleValidator()
         self._scaleLE.setValidator(validator)
@@ -35,12 +51,13 @@ class BinningWidget(qt.QMainWindow):
         self._resetB = _buttons.addButton(_buttons.Reset)
         self._abortB.hide()
 
-        self._applyB.clicked.connect(self._applyBinning)
-        self._okB.clicked.connect(self.apply)
-        self._resetB.clicked.connect(self.resetStack)
-        self._abortB.clicked.connect(self.abort)
+        self._applyB.released.connect(self._applyBinning)
+        self._okB.released.connect(self.apply)
+        self._resetB.released.connect(self.resetStack)
+        self._abortB.released.connect(self.sigAbort)
 
         self._sv = StackViewMainWindow()
+        self._sv.setKeepDataAspectRatio(True)
         self._sv.setColormap(
             Colormap(
                 name=darfix.config.DEFAULT_COLORMAP_NAME,
@@ -54,31 +71,37 @@ class BinningWidget(qt.QMainWindow):
         widget.setLayout(layout)
         self.setCentralWidget(widget)
 
+        # connect signal / slot
+        self._scaleLE.editingFinished.connect(self._scaleChanged)
+
     @property
-    def scale(self):
-        return self._scale
+    def scale(self) -> float:
+        return float(self._scaleLE.text())
 
     @scale.setter
-    def scale(self, scale):
-        self._scale = scale
-        self._scaleLE.setText(str(scale))
+    def scale(self, scale: float):
+        if scale != self.scale:
+            self._scaleLE.setText(str(scale))
+            self._scaleChanged()
 
-    def setDataset(
-        self, parent, dataset, indices=None, bg_indices=None, bg_dataset=None
-    ):
-        """
-        Dataset setter.
+    def _scaleChanged(self, *args, **kwargs):
+        self.sigScaleChanged.emit(self.scale)
 
-        :param Dataset dataset: dataset
-        """
-        self.parent = parent
-        self._dataset = dataset
+    def updateResultDataset(self, dataset: dtypes.ImageDataset):
         self._update_dataset = dataset
-        self.indices = indices
-        self.bg_indices = bg_indices
-        self.bg_dataset = bg_dataset
+        self.setStack(self._update_dataset)
+
+    def setDataset(self, dataset: dtypes.Dataset):
+        self._dataset = dataset.dataset
+        self._update_dataset = dataset.dataset
+        self.indices = dataset.indices
+        self.bg_indices = dataset.bg_indices
+        self.bg_dataset = dataset.bg_dataset
         self.setStack()
-        self._thread = OperationThread(self, self._dataset.apply_binning)
+        if self._display_tooltip_msg:
+            self.display_tooltip_msg()
+
+    def display_tooltip_msg(self):
         msg = qt.QMessageBox()
         msg.setIcon(qt.QMessageBox.Information)
         msg.setText(
@@ -90,12 +113,7 @@ class BinningWidget(qt.QMainWindow):
         )
         msg.setWindowTitle("Fit succeeded!")
         msg.setStandardButtons(qt.QMessageBox.Ok)
-        msg.exec_()
-
-    def _updateDataset(self, widget, dataset):
-        self._dataset = dataset
-        self._update_dataset = dataset
-        self._parent._updateDataset(widget, dataset)
+        msg.exec()
 
     def setStack(self, dataset=None):
         """
@@ -110,45 +128,29 @@ class BinningWidget(qt.QMainWindow):
         self._sv.setStack(dataset.get_data())
         self._sv.setFrameNumber(nframe)
 
-    def _applyBinning(self):
-        if not self._update_dataset.in_memory:
-            self._abortB.show()
+    def _startComputation(self):
         self._applyB.setEnabled(False)
         self._okB.setEnabled(False)
-        self.scale = float(self._scaleLE.text())
-        self._thread.setArgs(self.scale)
-        self._thread.finished.connect(self._updateData)
-        self._thread.start()
 
-    def _updateData(self):
-        self._thread.finished.disconnect(self._updateData)
+    def _endComputation(self):
         self._applyB.setEnabled(True)
+        self._okB.setEnabled(True)
         self._abortB.hide()
         self._abortB.setEnabled(True)
-        self._okB.setEnabled(True)
-        if self._thread.data:
-            self._update_dataset = self._thread.data
-            self.setStack(self._update_dataset)
+
+    def _applyBinning(self):
+        if self._dataset is None:
+            missing_dataset_msg()
+            return
+        self._startComputation()
+        self.sigApply.emit()
 
     def abort(self):
         self._abortB.setEnabled(False)
         self._update_dataset.stop_operation(Operation.BINNING)
 
     def apply(self):
-        """
-        Function that replaces the dataset data with the data shown in the stack of images.
-        If the stack has a roi applied, it applies the same roi to the dark frames of the dataset.
-        Signal emitted with the roi parameters.
-        """
-        if self.scale:
-            self.sigComputed.emit(
-                [self.scale] if type(self.scale) == int else self.scale
-            )
-        else:
-            self.sigComputed.emit([])
-
-    def getDataset(self):
-        return self._update_dataset, self.indices, self.bg_indices, self.bg_dataset
+        self.sigComputed.emit()
 
     def resetStack(self):
         """
