@@ -3,29 +3,13 @@ __license__ = "MIT"
 __date__ = "22/12/2020"
 
 import numpy
-
 from silx.gui import qt
-from silx.utils.enum import Enum as _Enum
 
-from .operationThread import OperationThread
+from darfix import dtypes
+from darfix.tasks.blindsourceseparation import Method
+
 from .displayComponentsWidget import DisplayComponentsWidget
-
-
-class Method(_Enum):
-    """
-    Different blind source separation approaches that can be applied
-    """
-
-    PCA = (
-        "The process of computing the principal components \n"
-        "and using them to perform a change of basis on the data"
-    )
-    NICA = "Find components independent from each other and non-negative"
-    NMF = (
-        "Non-negative matrix factorization factorizes the data matrix into \n"
-        "two matrices, with the property that all three matrices have no negative elements"
-    )
-    NICA_NMF = "Apply Non-negative ICA followed by NMF"
+from .operationThread import OperationThread
 
 
 class BSSWidget(qt.QMainWindow):
@@ -35,6 +19,16 @@ class BSSWidget(qt.QMainWindow):
 
     sigComputed = qt.Signal(Method, int)
 
+    sigNbComponentsChanged = qt.Signal(int)
+    """emit when the number of component has been changed"""
+
+    sigMethodChanged = qt.Signal(str)
+    """emit when the method (PCA, NICA...) changed"""
+
+    DEFAULT_METHOD = Method.PCA.value
+
+    DEFAULT_N_COMP = 1
+
     def __init__(self, parent=None):
         qt.QMainWindow.__init__(self, parent)
 
@@ -44,16 +38,20 @@ class BSSWidget(qt.QMainWindow):
         for member in Method.members():
             self.methodCB.addItem(member.name)
             self.methodCB.setItemData(
-                self.methodCB.count() - 1, member.value, qt.Qt.ToolTipRole
+                self.methodCB.count() - 1,
+                Method.get_description(member),
+                qt.Qt.ToolTipRole,
             )
+        self.methodCB.setCurrentText(self.DEFAULT_METHOD)
+        self.methodCB.currentTextChanged.connect(self.sigMethodChanged)
         # Number of components
         nComponentsLabel = qt.QLabel("Num comp:")
-        self.nComponentsLE = qt.QLineEdit("1")
+        self.nComponentsLE = qt.QLineEdit(str(self.DEFAULT_N_COMP))
         self.nComponentsLE.setValidator(qt.QIntValidator())
+        self.nComponentsLE.editingFinished.connect(self._nbComponentEdited)
         # Compute BSS with the number of components
         self.computeButton = qt.QPushButton("Compute")
         self.computeButton.setEnabled(False)
-        self.computeButton.clicked.connect(self._computeBSS)
         # Detect optimal number of components
         self.detectButton = qt.QPushButton("Detect number of components")
         self.detectButton.setEnabled(False)
@@ -81,63 +79,56 @@ class BSSWidget(qt.QMainWindow):
         self.splitter.addWidget(self._displayComponentsWidget)
         self.setCentralWidget(self.splitter)
 
+    def setMethod(self, method: Method):
+        if method in (None, ""):
+            method = self.DEFAULT_METHOD
+        method = Method.from_value(method)
+        self.methodCB.setCurrentText(method.value)
+
+    def getMethod(self) -> Method:
+        return Method.from_value(self.methodCB.currentText())
+
+    def setNComp(self, n_comp: int):
+        if n_comp in ("0", 0):
+            n_comp = self.DEFAULT_N_COMP
+        self.nComponentsLE.setText(str(n_comp))
+
+    def getNComp(self) -> int:
+        return int(self.nComponentsLE.text())
+
     def hideButton(self):
         self._computeB.hide()
 
     def showButton(self):
         self._computeB.show()
 
-    def setDataset(
-        self, parent, dataset, indices=None, bg_indices=None, bg_dataset=None
-    ):
-        """
-        Dataset setter.
-
-        :param Dataset dataset: dataset
-        """
-        self._parent = parent
-        self.dataset = dataset
-        self.indices = indices
-        self.bg_indices = bg_indices
-        self.bg_dataset = bg_dataset
+    def setDataset(self, dataset: dtypes.Dataset):
+        self.dataset = dataset.dataset
+        self.indices = dataset.indices
+        self.bg_indices = dataset.bg_indices
+        self.bg_dataset = dataset.bg_dataset
         self.computeButton.setEnabled(True)
         self.detectButton.setEnabled(True)
 
-    def _updateDataset(self, widget, dataset):
-        self._parent._updateDataset(widget, dataset)
-        self.dataset = dataset
+    def _nbComponentEdited(self, *args, **kwargs):
+        self.sigNbComponentsChanged.emit(int(self.nComponentsLE.text()))
 
-    def _computeBSS(self):
+    def _displayComponents(
+        self, dataset: dtypes.ImageDataset, indices, bg_indices, comp, W
+    ):
         """
-        Computes blind source separation with the chosen method.
+        :param dataset: dataset for which we want to display the components
+        :param indices: dataset indices
+        :param bg_indices: background indices
+        :param comp: components
+        :param W: Matrix with the rocking curves values
         """
-        self.computeButton.setEnabled(False)
-        self.detectButton.setEnabled(False)
-        self.nComponentsLE.setEnabled(False)
-        method = Method[self.methodCB.currentText()]
-        n_comp = int(self.nComponentsLE.text())
-        self.sigComputed.emit(method, n_comp)
-        if method == Method.PCA:
-            self._thread = OperationThread(self, self.dataset.pca)
-            self._thread.setArgs(n_comp, indices=self.indices)
-        elif method == Method.NICA:
-            self._thread = OperationThread(self, self.dataset.nica)
-            self._thread.setArgs(n_comp, indices=self.indices, error_step=5)
-        elif method == Method.NMF:
-            self._thread = OperationThread(self, self.dataset.nmf)
-            self._thread.setArgs(n_comp, indices=self.indices, error_step=5)
-        elif method == Method.NICA_NMF:
-            self._thread = OperationThread(self, self.dataset.nica_nmf)
-            self._thread.setArgs(n_comp, indices=self.indices, error_step=5)
-        else:
-            raise ValueError("BSS method not managed")
-
-        self._thread.finished.connect(self._displayComponents)
-        self._thread.start()
-
-    def _displayComponents(self):
-        self._thread.finished.disconnect(self._displayComponents)
-        comp, self.W = self._thread.data
+        if not isinstance(dataset, dtypes.ImageDataset):
+            raise TypeError(
+                f"dataset is expected to be an instance of {dtypes.ImageDataset}. Got {type(dataset)}."
+            )
+        # self._thread.finished.disconnect(self._displayComponents)
+        # comp, self.W = self._thread.data
         n_comp = int(self.nComponentsLE.text())
         if comp.shape[0] < n_comp:
             n_comp = comp.shape[0]
@@ -145,26 +136,25 @@ class BSSWidget(qt.QMainWindow):
             msg.setIcon(qt.QMessageBox.Information)
             msg.setText("Found only {0} components".format(n_comp))
             msg.setStandardButtons(qt.QMessageBox.Ok)
-            msg.exec_()
-        shape = self.dataset.get_data()[0].shape
-        self.comp = comp.reshape(n_comp, shape[0], shape[1])
+            msg.exec()
+        shape = dataset.get_data()[0].shape
+        comp = comp.reshape(n_comp, shape[0], shape[1])
         self._displayComponentsWidget.show()
         self.computeButton.setEnabled(True)
         self.nComponentsLE.setEnabled(True)
         self.detectButton.setEnabled(True)
-        if self.bg_indices is not None:
+        if bg_indices is not None:
             # If filter data is activated, the matrix W has reduced dimensionality, so reshaping is not possible
             # Create empty array with shape the total number of frames
-            W = numpy.zeros((self.dataset.nframes, n_comp))
+            W = numpy.zeros((dataset.nframes, n_comp))
             # Set actual values of W where threshold of filter is True
-            W[self.indices] = self.W
-            self.W = W
+            W[indices] = W
         self._displayComponentsWidget.setComponents(
-            self.comp,
-            self.W,
-            self.dataset.dims,
-            self.dataset.get_dimensions_values(),
-            self.dataset.title,
+            comp,
+            W,
+            dataset.dims,
+            dataset.get_dimensions_values(),
+            dataset.title,
         )
 
     def _detectComp(self):
@@ -183,6 +173,7 @@ class BSSWidget(qt.QMainWindow):
         self.detectButton.setEnabled(True)
         self.computeButton.setEnabled(True)
         self.nComponentsLE.setText(str(components))
+        self.sigNbComponentsChanged.emit(components)
 
     def getDisplayComponentsWidget(self):
         return self._displayComponentsWidget
