@@ -3,16 +3,17 @@ __license__ = "MIT"
 __date__ = "12/04/2022"
 
 import numpy
-
-from silx.gui import qt
 from silx.gui import icons
+from silx.gui import qt
 from silx.gui.colors import Colormap
-from silx.gui.plot import ScatterView, StackView, Plot1D
-import silx.resources
+from silx.gui.plot import Plot1D
+from silx.gui.plot import ScatterView
+from silx.gui.plot import StackView
 
 import darfix
 from darfix.io.utils import write_components
-from .utils import ChooseDimensionDock
+
+from .chooseDimensions import ChooseDimensionDock
 
 
 class DisplayComponentsWidget(qt.QMainWindow):
@@ -32,6 +33,7 @@ class DisplayComponentsWidget(qt.QMainWindow):
                 normalization=darfix.config.DEFAULT_COLORMAP_NORM,
             )
         )
+        self._sv_components.setKeepDataAspectRatio(True)
         self._sv_components.setGraphTitle("Components")
         self._mixing_plots_widget = MixingPlotsWidget(self)
         self._mixing_plots_widget.activeCurveChanged.connect(self._setComponent)
@@ -90,7 +92,7 @@ class DisplayComponentsWidget(qt.QMainWindow):
         fileDialog.setAcceptMode(fileDialog.AcceptSave)
         fileDialog.setOption(fileDialog.DontUseNativeDialog)
         fileDialog.setDefaultSuffix(".h5")
-        if fileDialog.exec_():
+        if fileDialog.exec():
             write_components(
                 fileDialog.selectedFiles()[0],
                 "entry",
@@ -152,8 +154,6 @@ class MixingPlotsWidget(qt.QMainWindow):
 
         self._toolbar = qt.QToolBar(parent=self)
         self._toolbar.setIconSize(self._toolbar.iconSize() * 1.2)
-        if "darfix" not in silx.resources._RESOURCE_DIRECTORIES:
-            silx.resources.register_resource_directory("darfix", "darfix.resources")
         curves_icon = icons.getQIcon("darfix:gui/icons/curves")
         scatter_icon = icons.getQIcon("darfix:gui/icons/scatter")
         self.curves_action = qt.QAction(curves_icon, "Curves", self)
@@ -184,7 +184,6 @@ class MixingPlotsWidget(qt.QMainWindow):
         return self._rsm_scatter
 
     def updatePlots(self, dimensions, mixing_matrix, dimensions_values):
-
         self.dimensions = dimensions
         self.mixing_matrix = mixing_matrix
         self.is2dimensional(True if dimensions.ndim == 2 else False)
