@@ -4,13 +4,14 @@ __date__ = "30/11/2020"
 
 
 import numpy
-
 from silx.gui import qt
 from silx.gui.colors import Colormap
-from silx.gui.plot import Plot1D, Plot2D
+from silx.gui.plot import Plot1D
+from silx.gui.plot import Plot2D
 
 import darfix
-from darfix.gui.datasetSelectionWidget import FilenameSelectionWidget
+
+from .data_selection.edf import FilenameSelectionWidget
 
 
 class LineProfileWidget(qt.QMainWindow):
