@@ -3,22 +3,22 @@ __license__ = "MIT"
 __date__ = "07/06/2021"
 
 
-import numpy
 from pathlib import Path
 
+import numpy
 from silx.gui import qt
 from silx.gui.colors import Colormap
 from silx.gui.plot import StackView
 from silx.gui.plot.items import Scatter
-import darfix
-from darfix.core.dimension import AcquisitionDims
-from darfix.core.componentsMatching import ComponentsMatching, Method
-from darfix.gui.datasetSelectionWidget import FilenameSelectionWidget
-from darfix.gui.displayComponentsWidget import MixingPlotsWidget
-from darfix.io.utils import read_components
-import logging
 
-_logger = logging.getLogger(__file__)
+import darfix
+from darfix.core.componentsMatching import ComponentsMatching
+from darfix.core.componentsMatching import Method
+from darfix.core.dimension import AcquisitionDims
+from darfix.io.utils import read_components
+
+from .data_selection.edf import FilenameSelectionWidget
+from .displayComponentsWidget import MixingPlotsWidget
 
 
 class LinkComponentsWidget(qt.QMainWindow):
@@ -52,7 +52,7 @@ class LinkComponentsWidget(qt.QMainWindow):
         self._checkbox = qt.QCheckBox("Link features", self)
         self._checkbox.setChecked(True)
         self._checkbox.setToolTip("If checked, lines between matches will be drawn")
-        self._checkbox.stateChanged.connect(self._checkBoxToggled)
+        self._checkbox.toggled.connect(self._checkBoxToggled)
         checkbox_widget = qt.QWidget(parent=self)
         checkbox_layout = qt.QHBoxLayout()
         checkbox_layout.addWidget(self._checkbox)
@@ -62,6 +62,7 @@ class LinkComponentsWidget(qt.QMainWindow):
 
         # Stack 1
         self._sv1 = StackView(parent=self)
+        self._sv1.setKeepDataAspectRatio(True)
         self._sv1.setColormap(
             Colormap(name=darfix.config.DEFAULT_COLORMAP_NAME, normalization="linear")
         )
@@ -84,6 +85,7 @@ class LinkComponentsWidget(qt.QMainWindow):
 
         # Stack 2
         self._sv2 = StackView(parent=self)
+        self._sv2.setKeepDataAspectRatio(True)
         self._sv2.setColormap(
             Colormap(name=darfix.config.DEFAULT_COLORMAP_NAME, normalization="linear")
         )
@@ -106,6 +108,7 @@ class LinkComponentsWidget(qt.QMainWindow):
 
         # Linked stack
         self._linked_sv = StackView(parent=self)
+        self._linked_sv.setKeepDataAspectRatio(True)
         self._linked_sv.setColormap(
             Colormap(name=darfix.config.DEFAULT_COLORMAP_NAME, normalization="linear")
         )
@@ -128,7 +131,7 @@ class LinkComponentsWidget(qt.QMainWindow):
                 msg = qt.QMessageBox()
                 msg.setIcon(qt.QMessageBox.Warning)
                 msg.setText("Filename not valid")
-                msg.exec_()
+                msg.exec()
             return
 
         dims, self.components1, self.W1, values = read_components(filename)
@@ -178,18 +181,17 @@ class LinkComponentsWidget(qt.QMainWindow):
         self._computeB.setEnabled(True)
         self._computeB.pressed.connect(self._linkComponents)
 
-    def _checkBoxToggled(self, linkFeatures):
+    def _checkBoxToggled(self, linkFeatures: bool):
         """
         Slot to toggle state in function of the checkbox state.
         """
         self._displayMatches = linkFeatures
 
     def _comboBoxChanged(self, text):
-
         method = Method(text)
         if method == Method.orb_feature_matching:
             self._checkbox.setEnabled(True)
-            self._displayMatches = self._checkbox.checkState()
+            self._displayMatches = True
         else:
             self._checkbox.setEnabled(False)
             self._displayMatches = False
