@@ -1,73 +1,73 @@
-__authors__ = ["J. Garriga"]
-__license__ = "MIT"
-__date__ = "25/04/2022"
+from __future__ import annotations
 
+from typing import List
 
 import numpy
 from silx.gui import qt
 from silx.gui.colors import Colormap
 from silx.gui.plot import Plot2D
 from silx.io.dictdump import dicttonx
-from darfix.io.utils import create_nxdata_dict
-from .rsmWidget import PixelSize
-from .operationThread import OperationThread
+
+from ..dtypes import Dataset
+from ..io.utils import create_nxdata_dict
+from ..pixel_sizes import PixelSize
 
 
-class RSMHistogramWidget(qt.QMainWindow):
+class _LineEditsWidget(qt.QWidget):
+    def __init__(self, parent, dims=1, validator=None, placeholder=None):
+        qt.QWidget.__init__(self, parent)
+        layout = qt.QHBoxLayout()
+        if placeholder:
+            assert len(placeholder) == dims
+        self._lineEdits = []
+        for i in range(dims):
+            lineEdit = qt.QLineEdit(parent=self)
+            if placeholder:
+                lineEdit.setPlaceholderText(placeholder[i])
+            if validator:
+                lineEdit.setValidator(validator)
+            self._lineEdits.append(lineEdit)
+            layout.addWidget(lineEdit)
+
+        layout.setContentsMargins(0, 0, 0, 0)
+        self.setLayout(layout)
+
+    @property
+    def value(self):
+        values = []
+        for le in self._lineEdits:
+            values += [le.text() if le.text() != "" else None]
+        return values
+
+    def setValue(self, values: List[int]):
+        assert type(values) is list
+
+        for i, value in enumerate(values):
+            self._lineEdits[i].setText(str(value))
+            self._lineEdits[i].setCursorPosition(0)
+
+
+class RSMHistogramWidget(qt.QWidget):
     """
     Widget to compute Reciprocal Space Map
     """
 
-    sigComputed = qt.Signal()
-
-    class _LineEditsWidget(qt.QWidget):
-        def __init__(self, parent, dims=1, validator=None, placeholder=None):
-            qt.QWidget.__init__(self, parent)
-            self.setLayout(qt.QHBoxLayout())
-            if placeholder:
-                assert len(placeholder) == dims
-            self._lineEdits = []
-            for i in range(dims):
-                lineEdit = qt.QLineEdit(parent=self)
-                if placeholder:
-                    lineEdit.setPlaceholderText(placeholder[i])
-                if validator:
-                    lineEdit.setValidator(validator)
-                self._lineEdits.append(lineEdit)
-                self.layout().addWidget(lineEdit)
-
-            self.layout().setContentsMargins(0, 0, 0, 0)
-
-        @property
-        def value(self):
-            values = []
-            for le in self._lineEdits:
-                values += [le.text() if le.text() != "" else None]
-            return values
-
-        def setValue(self, values):
-            """
-            :param int or None _range
-            """
-            assert type(values) is list
-
-            for i, value in enumerate(values):
-                self._lineEdits[i].setText(str(value))
-                self._lineEdits[i].setCursorPosition(0)
+    sigComputeClicked = qt.Signal()
 
     def __init__(self, parent=None):
-        qt.QMainWindow.__init__(self, parent)
+        super().__init__(parent=parent)
+
+        self.dataset: Dataset | None = None
 
         self._idx = [(2, 1), (2, 0), (1, 0)]
 
-        widget = qt.QWidget(parent=self)
         layout = qt.QGridLayout()
         label = qt.QLabel("Q:")
         font = label.font()
         font.setBold(True)
         label.setFont(font)
         layout.addWidget(label, 0, 0, 1, 1)
-        self._q = self._LineEditsWidget(self, 3, qt.QIntValidator(), ["h", "k", "l"])
+        self._q = _LineEditsWidget(self, 3, qt.QIntValidator(), ["h", "k", "l"])
         self._q.setValue([1, 0, 1])
         layout.addWidget(self._q, 0, 1, 1, 2)
         label = qt.QLabel("Pseudocubic lattice:")
@@ -75,14 +75,14 @@ class RSMHistogramWidget(qt.QMainWindow):
         layout.addWidget(label, 1, 0, 1, 2)
         self._a = qt.QLineEdit()
         self._a.setValidator(qt.QDoubleValidator())
-        self._a.setText("4.08")
+        self.a = 4.08
         layout.addWidget(self._a, 1, 1, 1, 2)
         label = qt.QLabel("Map range:")
         label.setFont(font)
         layout.addWidget(label, 2, 0, 1, 2)
         self._map_range = qt.QLineEdit()
         self._map_range.setValidator(qt.QDoubleValidator())
-        self._map_range.setText("0.008")
+        self.map_range = 0.008
         layout.addWidget(self._map_range, 2, 1, 1, 2)
         label = qt.QLabel("Detector:")
         label.setFont(font)
@@ -99,15 +99,13 @@ class RSMHistogramWidget(qt.QMainWindow):
         label = qt.QLabel("n:")
         label.setFont(font)
         layout.addWidget(label, 5, 0, 1, 1)
-        self._n = self._LineEditsWidget(self, 3, qt.QIntValidator(), ["h", "k", "l"])
+        self._n = _LineEditsWidget(self, 3, qt.QIntValidator(), ["h", "k", "l"])
         self._n.setValue([0, 1, 0])
         layout.addWidget(self._n, 5, 1, 1, 2)
         label = qt.QLabel("Map shape:")
         label.setFont(font)
         layout.addWidget(label, 6, 0, 1, 1)
-        self._map_shape = self._LineEditsWidget(
-            self, 3, qt.QIntValidator(), ["x", "y", "z"]
-        )
+        self._map_shape = _LineEditsWidget(self, 3, qt.QIntValidator(), ["x", "y", "z"])
         self._map_shape.setValue([200, 200, 200])
         layout.addWidget(self._map_shape, 6, 1, 1, 2)
         label = qt.QLabel("Energy:")
@@ -115,11 +113,11 @@ class RSMHistogramWidget(qt.QMainWindow):
         layout.addWidget(label, 7, 0, 1, 2)
         self._energy = qt.QLineEdit()
         self._energy.setValidator(qt.QDoubleValidator())
-        self._energy.setText("17")
+        self.energy = 17
         layout.addWidget(self._energy, 7, 1, 1, 2)
         self._computeB = qt.QPushButton("Compute")
         layout.addWidget(self._computeB, 8, 2, 1, 1)
-        self._computeB.clicked.connect(self._computeRSM)
+        self._computeB.clicked.connect(self.sigComputeClicked.emit)
         self._plotWidget = qt.QWidget()
         self._plotWidget.setLayout(qt.QHBoxLayout())
         layout.addWidget(self._plotWidget, 9, 0, 1, 3)
@@ -129,23 +127,11 @@ class RSMHistogramWidget(qt.QMainWindow):
         layout.addWidget(self._exportButton, 10, 2, 1, 1)
         self._exportButton.clicked.connect(self.exportMaps)
 
-        widget.setLayout(layout)
-        widget.setMinimumWidth(650)
-        self.setCentralWidget(widget)
+        self.setLayout(layout)
+        self.setMinimumWidth(650)
 
-    def setDataset(
-        self, parent, dataset, indices=None, bg_indices=None, bg_dataset=None
-    ):
-        """
-        Dataset setter.
-
-        :param Dataset dataset: dataset
-        """
-        self._parent = parent
+    def setDataset(self, dataset: Dataset):
         self.dataset = dataset
-        self.indices = indices
-        self._update_dataset = dataset
-        self._thread = OperationThread(self, self.dataset.apply_fit)
         for i in reversed(range(self._plotWidget.layout().count())):
             self._plotWidget.layout().itemAt(i).widget().setParent(None)
 
@@ -158,38 +144,45 @@ class RSMHistogramWidget(qt.QMainWindow):
             self._plots[-1].setDefaultColormap(Colormap(name="viridis"))
             self._plotWidget.layout().addWidget(self._plots[-1])
 
-        self._thread = OperationThread(self, self.dataset.compute_rsm)
+    def _toFloat(self, text: str) -> float:
+        value, ok = self.locale().toFloat(text)
+        if not ok:
+            raise ValueError(f"Could not convert string to float: '{text}'")
+        return value
+
+    def _toStr(self, value: float) -> str:
+        return self.locale().toString(value)
 
     @property
     def q(self):
         return numpy.array(self._q.value, dtype=int)
 
     @q.setter
-    def q(self, q):
+    def q(self, q: List[int]):
         self._q.setValue(q)
 
     @property
     def a(self):
-        return float(self._a.text())
+        return self._toFloat(self._a.text())
 
     @a.setter
-    def a(self, a):
-        self._a.setText(str(a))
+    def a(self, a: float):
+        self._a.setText(self._toStr(a))
 
     @property
     def map_range(self):
-        return float(self._map_range.text())
+        return self._toFloat(self._map_range.text())
 
     @map_range.setter
-    def map_range(self, map_range):
-        self._map_range.setText(str(map_range))
+    def map_range(self, map_range: float):
+        self._map_range.setText(self._toStr(map_range))
 
     @property
     def detector(self):
         return self._detector.currentText()
 
     @detector.setter
-    def detector(self, detector):
+    def detector(self, detector: str):
         self._detector.setCurrentText(detector)
 
     @property
@@ -197,7 +190,7 @@ class RSMHistogramWidget(qt.QMainWindow):
         return self._units.currentText()
 
     @units.setter
-    def units(self, units):
+    def units(self, units: str):
         self._units.setCurrentText(units)
 
     @property
@@ -205,7 +198,7 @@ class RSMHistogramWidget(qt.QMainWindow):
         return numpy.array(self._n.value, dtype=int)
 
     @n.setter
-    def n(self, n):
+    def n(self, n: List[int]):
         self._n.setValue(n)
 
     @property
@@ -213,73 +206,47 @@ class RSMHistogramWidget(qt.QMainWindow):
         return numpy.array(self._map_shape.value, dtype=int)
 
     @map_shape.setter
-    def map_shape(self, map_shape):
+    def map_shape(self, map_shape: List[int]):
         self._map_shape.setValue(map_shape)
 
     @property
     def energy(self):
-        return float(self._energy.text())
+        return self._toFloat(self._energy.text())
 
     @energy.setter
-    def energy(self, energy):
-        self._energy.setText(str(energy))
+    def energy(self, energy: float):
+        self._energy.setText(self._toStr(energy))
 
-    def _computeRSM(self):
+    def updatePlot(self, arr: numpy.ndarray, edges: numpy.ndarray):
+        arr = numpy.nan_to_num(arr)
 
-        self._computeB.setEnabled(False)
-        self._thread.setArgs(
-            Q=self.q,
-            a=self.a,
-            map_range=self.map_range,
-            pixel_size=numpy.array(PixelSize[self.detector].value, dtype=float),
-            units=self.units.lower(),
-            n=self.n,
-            map_shape=self.map_shape,
-            energy=self.energy,
-        )
-        self.sigComputed.emit()
-        self._thread.finished.connect(self._updateData)
-        self._thread.start()
-
-    def _updateData(self):
-        self._thread.finished.disconnect(self._updateData)
-        self._computeB.setEnabled(True)
-
-        if self._thread.data is not None:
-            arr, edges = self._thread.data
-
-            arr = numpy.nan_to_num(arr)
-
-            self._projections = []
-
-            if self._units.currentText().lower() == "poulsen":
-                self.labels = [r"$q_{rock}$", r"$q_{\perp}$", r"$q_{||}$"]
-            else:
-                self.labels = ["h", "k", "l"]
-
-            for idx, (i, j) in enumerate(self._idx):
-                self._projections += [numpy.sum(arr, axis=idx)]
-                xscale = (edges[i][-1] - edges[i][0]) / len(edges[i])
-                yscale = (edges[j][-1] - edges[j][0]) / len(edges[j])
-                self._plots[idx].addImage(
-                    self._projections[-1],
-                    scale=(xscale, yscale),
-                    origin=(edges[i][0], edges[j][0]),
-                    xlabel=self.labels[i],
-                    ylabel=self.labels[j],
-                )
-
-            self.edges = edges
-
-            self._plotWidget.show()
-            self._exportButton.show()
+        self._projections = []
 
+        if self._units.currentText().lower() == "poulsen":
+            self.labels = [r"$q_{rock}$", r"$q_{\perp}$", r"$q_{||}$"]
         else:
-            print("\nComputation aborted")
+            self.labels = ["h", "k", "l"]
+
+        for idx, (i, j) in enumerate(self._idx):
+            self._projections += [numpy.sum(arr, axis=idx)]
+            xscale = (edges[i][-1] - edges[i][0]) / len(edges[i])
+            yscale = (edges[j][-1] - edges[j][0]) / len(edges[j])
+            self._plots[idx].addImage(
+                self._projections[-1],
+                scale=(xscale, yscale),
+                origin=(edges[i][0], edges[j][0]),
+                xlabel=self.labels[i],
+                ylabel=self.labels[j],
+            )
+
+        self._edges = edges
+
+        self._plotWidget.show()
+        self._exportButton.show()
 
     def exportMaps(self):
         """
-        Creates dictionay with maps information and exports it to a nexus file
+        Creates dictionary with maps information and exports it to a nexus file
         """
         entry = "entry"
 
@@ -290,7 +257,7 @@ class RSMHistogramWidget(qt.QMainWindow):
         }
 
         for idx, (j, i) in enumerate(self._idx):
-            axis = [self.edges[i][:-1], self.edges[j][:-1]]
+            axis = [self._edges[i][:-1], self._edges[j][:-1]]
             nx["entry"][str(idx)] = create_nxdata_dict(
                 self._projections[idx],
                 self.labels[i] + "_" + self.labels[j],
@@ -304,5 +271,5 @@ class RSMHistogramWidget(qt.QMainWindow):
         fileDialog.setAcceptMode(fileDialog.AcceptSave)
         fileDialog.setOption(fileDialog.DontUseNativeDialog)
         fileDialog.setDefaultSuffix(".h5")
-        if fileDialog.exec_():
+        if fileDialog.exec():
             dicttonx(nx, fileDialog.selectedFiles()[0])
