@@ -5,15 +5,16 @@ __date__ = "03/12/2020"
 import glob
 import os
 
-from silx.io import fabioh5
-from silx.io.url import DataUrl
 from silx.gui import qt
 from silx.gui.colors import Colormap
 from silx.gui.plot.StackView import StackViewMainWindow
+from silx.io import fabioh5
+from silx.io.url import DataUrl
 
 import darfix
 from darfix.core.dataset import Data
-from darfix.gui.datasetSelectionWidget import DirSelectionWidget
+
+from .data_selection.WorkingDirSelectionWidget import WorkingDirSelectionWidget
 
 
 class ShowStackWidget(qt.QMainWindow):
@@ -27,13 +28,14 @@ class ShowStackWidget(qt.QMainWindow):
         qt.QWidget.__init__(self, parent)
 
         layout = qt.QVBoxLayout()
-        self._filenameData = DirSelectionWidget(parent=self)
+        self._filenameData = WorkingDirSelectionWidget(parent=self)
         self._filenameData.dirChanged.connect(self.updateStack)
         layout.addWidget(self._filenameData)
         self._sv = StackViewMainWindow()
         self._sv.setColormap(
             Colormap(name=darfix.config.DEFAULT_COLORMAP_NAME, normalization="linear")
         )
+        self._sv.setKeepDataAspectRatio(True)
         self._sv.hide()
         layout.addWidget(self._sv)
         widget = qt.QWidget(parent=self)
