@@ -3,12 +3,13 @@ __license__ = "MIT"
 __date__ = "12/06/2020"
 
 import json
-import numpy
 
+import numpy
 from silx.io import fabioh5
 from silx.io.url import DataUrl
 
-from darfix.core.dataset import Data, Dataset
+from darfix.core.dataset import Data
+from darfix.core.dataset import ImageDataset
 from darfix.core.dimension import AcquisitionDims
 
 
@@ -59,7 +60,7 @@ def load_from_json(filename):
         else:
             dims = None
         data = Data(urls, metadata, distro["in_memory"]).reshape(distro["shape"])
-        dataset = Dataset(
+        dataset = ImageDataset(
             _dir=distro["dir"], data=data, in_memory=distro["in_memory"], dims=dims
         )
 
