@@ -1,16 +1,17 @@
-__authors__ = ["J. Garriga"]
-__license__ = "MIT"
-__date__ = "03/07/2021"
-
+import importlib.metadata
 import logging
-import h5py
+import sys
 from datetime import datetime
-import numpy
 
-from silx.io.dictdump import dicttoh5, h5todict
+import h5py
+import numpy
+from silx.io.dictdump import dicttoh5
+from silx.io.dictdump import h5todict
 
 _logger = logging.getLogger(__file__)
 
+_VERSION = importlib.metadata.version("darfix")
+
 
 def assert_string(s, enums):
     s += " has to be "
@@ -57,10 +58,10 @@ def advancement_display(
     filledLength = int(length * min(progress, 1))
     leftLength = length - filledLength
     bar = fill * filledLength + left * leftLength
-    print("\r%s |%s| %s%% %s" % (prefix, bar, percent, suffix), end="\r")
+    sys.stdout.write("\r%s |%s| %s%% %s\r" % (prefix, bar, percent, suffix))
     # Print New Line on Complete
     if ncurrent >= ntotal:
-        print()
+        sys.stdout.write("\n")
 
 
 def write_maps(
@@ -131,7 +132,7 @@ def write_maps(
                 if key in nx_process:
                     del nx_process[key]
         nx_process["program"] = "darfix"
-        nx_process["version"] = "0.2"
+        nx_process["version"] = _VERSION
         nx_process["date"] = datetime.now().replace(microsecond=0).isoformat()
         nx_process["processing_order"] = numpy.int32(processing_order)
 
@@ -253,7 +254,7 @@ def write_components(
                 if key in nx_process:
                     del nx_process[key]
         nx_process["program"] = "darfix"
-        nx_process["version"] = "0.2"
+        nx_process["version"] = _VERSION
         nx_process["date"] = datetime.now().replace(microsecond=0).isoformat()
         nx_process["processing_order"] = numpy.int32(processing_order)
 
@@ -281,13 +282,16 @@ def write_components(
 
 
 def create_nxdata_dict(
-    signal, signal_name, axes=None, axes_names=None, axes_long_names=None, rgba=False
+    signal: numpy.ndarray,
+    signal_name: str,
+    axes=None,
+    axes_names=None,
+    axes_long_names=None,
+    rgba=False,
 ):
-
     nxdata = {signal_name: signal, "@signal": signal_name, "@NX_class": "NXdata"}
 
     if axes is not None:
-
         nxdata.update(
             {"@axes": axes_names, axes_names[0]: axes[0], axes_names[1]: axes[1]}
         )
@@ -302,5 +306,6 @@ def create_nxdata_dict(
 
     if rgba:
         nxdata[signal_name + "@interpretation"] = "rgba-image"
+        nxdata[signal_name + "@CLASS"] = "IMAGE"
 
     return nxdata
