@@ -16,7 +16,7 @@ WIDGET_HELP_PATH = (
     # make htmlhelp
     # inside doc folder
     # ("{DEVELOP_ROOT}/doc/build/htmlhelp/index.html", None),
-    ("{DEVELOP_ROOT}/build/sphinx/htmlhelp/index.html", None),
+    ("{DEVELOP_ROOT}/build/sphinx/html/index.html", None),
     # Documentation included in wheel
     # Correct DATA_FILES entry is needed in setup.py and documentation has to be built
     # before the wheel is created.
