@@ -2,13 +2,16 @@ __authors__ = ["J. Garriga"]
 __license__ = "MIT"
 __date__ = "20/11/2020"
 
-from Orange.widgets.widget import OWWidget
+from ewoksorange.bindings.owwidgets import OWWidget
+
 from darfix.gui.lineProfileWidget import LineProfileWidget
 
 
 class LineProfileWidgetOW(OWWidget):
     """
-    Widget that computes the background substraction from a dataset
+    Widget that can display a line from an image.
+
+    This widget have no input / output and setting the image must be done manually.
     """
 
     name = "line profile"
