@@ -2,13 +2,17 @@ __authors__ = ["J. Garriga"]
 __license__ = "MIT"
 __date__ = "20/11/2020"
 
-from Orange.widgets.widget import OWWidget
+from ewoksorange.bindings.owwidgets import OWWidget
+
 from darfix.gui.linkComponentsWidget import LinkComponentsWidget
 
 
 class LinkComponentsWidgetOW(OWWidget):
     """
-    Widget that computes the background substraction from a dataset
+    Widget that compare two stacks of images. Each of these stacks represents the
+    components of a dataset.
+
+    This widget have no input / output and setting the image must be done manually.
     """
 
     name = "link components"
